@@ -77,21 +77,5 @@ X11_write_clip <- function(content, object_type, breaks, eos, return_new, ...) {
 
   .dots <- list(...)
 
-  # If no custom line separator has been specified, use Unix's default newline
-  # character '\n'
-  breaks <- ifelse(is.null(breaks), '\n', breaks)
-
-  # If no custom tab separator for tables has been specified, use Unix's default
-  # tab character: '\t'
-  .dots$sep <- ifelse(is.null(.dots$sep), '\t', .dots$sep)
-
-  # Pass the object to rendering functions before writing out to the clipboard
-  rendered_content <- render_object(content, object_type, breaks, .dots)
-  writeChar(rendered_content, con = con, eos = eos)
-  close(con)
-  if (return_new) {
-    rendered_content
-  } else {
-    content
-  }
+  write_nix(content, object_type, breaks, eos, return_new, con, .dots)
 }
